==============================
Introduction
==============================

.. contents::


.. image:: https://secure.travis-ci.org/collective/collective.z3cform.chosen.png
    :target: http://travis-ci.org/collective/collective.z3cform.chosen

Credits
========
Companies
---------
|makinacom|_

  * `Planet Makina Corpus <http://www.makina-corpus.org>`_
  * `Contact us <mailto:python@makina-corpus.org>`_

.. |makinacom| image:: http://depot.makina-corpus.org/public/logo.gif
.. _makinacom:  http://www.makina-corpus.com

Authors
------------

- kiorky  <kiorky@cryptelium.net>

Contributors
-----------------

Description
=============
This package contains 4 widgets for z3cform using the `chosen <http://harvesthq.github.com/chosen/>`_ and `ajaxchosen <https://github.com/kiorky/ajax-chosen>`_ libraries.

 - A single valued widget for chosen
 - A multi valued widget for chosen
 - A single valued widget for ajaxchosen
 - A multi valued widget for ajaxchosen


Repository : `github <https://github.com/kiorky/collective.z3cform.chosen>`_


